@@ -4,7 +4,7 @@ import os
 #   1. In the git repository, where ./profiles/ exist
 #   2. When executing from a remote directory, but targeted a script that starts from the git repository
 #   3. When executing as a python -m archinstall module where profiles exist one step back for library reasons.
-#   (4. Added the ~/.config directory as a additional option for future reasons)
+#   (4. Added the ~/.config directory as an additional option for future reasons)
 #
 # And Keeping this in dict ensures that variables are shared across imports.
 storage = {
@@ -18,5 +18,8 @@ storage = {
 	'PROFILE_DB': None,  # Used in cases when listing profiles is desired, not mandatory for direct profile grabing.
 	'LOG_PATH': '/var/log/archinstall',
 	'LOG_FILE': 'install.log',
-	'MOUNT_POINT': '/mnt',
+	'MOUNT_POINT': '/mnt/archinstall',
+	'ENC_IDENTIFIER': 'ainst',
+	'DISK_TIMEOUTS' : 1, # seconds
+	'DISK_RETRY_ATTEMPTS' : 20, # RETRY_ATTEMPTS * DISK_TIMEOUTS is used in disk operations
 }
